% Pegel Innsbruck, Inn 1870 - 2005
 
% Extremwerte der Abflsse 1870 - 2005

HQ = [642
1207
915
672
624
651
912
1015
736
912
660
720
473
912
690
830
542
571
980
600
846
896
720
571
542
571
879
814
630
571
767
929
711
705
745
782
736
879
705
639
912
846
757
654
782
639
767
788
645
936
912
528
773
669
830
536
814
814
872
782
618
994
577
773
486
963
798
879
808
717
687
729
779
557
651
811
811
630
1040
420
620
920
725
800
950
900
820
755
915
620
1080
810
760
780
500
1050
750
870
680
530
760
550
490
590
660
1030
445
713
797
702
778
702
666
676
636
1159
736
1126
582
658
653
945
662
504
554
705
532
725
578
938
673
815
612
582
684
1525];

% Anpassung der zweiparametrigen Gumbelverteilung (Plate, p. 154):

muy = mean(HQ);  
sigmay = std(HQ); 
lambda = pi/(sigmay*sqrt(6)) 
y0 = muy - 0.577216/lambda 

n = length(HQ);

y = 200:1800;
% Dichte der Gumbelverteilung
fy = exp(-lambda*(y-y0)).*exp(-exp(-lambda*(y-y0)))*lambda;


% Darstellung als Histogramm
figure
hold on
Z = 400:100:1700; % Mittelpunkte der Bins, Binbreite = 100
N1 = hist(HQ,Z); 

Y1 = N1/13600; % N1 dividiert durch Gesamtzahl n = 136 mal Binbreite 100
bar(Z,Y1,1)
h = findobj(gca,'Type','patch');
set(h,'FaceColor','w','Edgecolor','k','LineWidth',1.5); % Histogramm schwarz-wei
plot([200 1700],[0 0],'k-','LineWidth',1.5)

plot(y,fy,'r-','LineWidth',2)

axis([200 1700 0 0.0032])
set(GCA, 'FontSize',12)
set(gca,'YTick',[0.0005 0.001 0.0015 0.002 0.0025 0.003])
set(gca,'YTicklabel',{'0.0005'; '0.001'; '0.0015'; '0.002'; '0.0025'; '0.003'})
legend('rel. Hufigkeit', 'Gumbelverteilung')
title('Inn 1870 - 2005: Jahresmaxima - HQ [m^3/s]')
box off
hold off


% Plot fr kumulative Gumbelverteilung
figure
plot(y,cumsum(fy),'r-','LineWidth',1.5)
axis([200 1700 -0.05 1.05])
grid
set(GCA, 'FontSize',12)
title('Inn: Jahresmaxima, berschreitenswahrscheinlichkeit')
box off


% Vergleich mit den Daten fr HQ:
% Mit Schrittweite 1/134 nicht ganz astrein!

figure
hold on
plot(sort(HQ),0:1/135:1,'b','Linewidth',1.5)
plot(y,cumsum(fy),'r','Linewidth',1.5)
axis([200 1700 -0.05 1.05])
grid
set(GCA, 'FontSize',12)
legend('Daten','Anpassung',0)
title('Inn 1870 - 2005, Jahresmaxima und Gumbelverteilung kumulativ')
hold off

% Wahrscheinlichkeit von 1525
lambda = 0.0076
y0 = 673.0466
W = quadl(inline('0.0076.*exp(-0.0076.*(x-673.0466)).*exp(-exp(-0.0076.*(x-673.0466)))'),0,1525)
% Jhrlichkeit
J = round(1/(1-W))    %  649 (berechnet)

% Berechnung der Jhrlichkeiten

x = 400:0.01:2000;
% Wahrscheinlichkeit von x
W = exp(-exp(-lambda*(x-y0))); 
% Jhrlichkeit
J = (1./(1-W));


%Quantile mit p = W von oben
Qp = y0 - log(-log(W))/lambda;
Kp = (Qp - muy)/sigmay;
sigmaQp = sigmay*sqrt((1 + 1.1396*Kp + 1.1*Kp.^2)/n); 


figure
semilogx(J,x,'k','linewidth',1.5)
hold on
semilogx(J,x+1.96*sigmaQp,'r','linewidth',1.5)
semilogx(J,x-1.96*sigmaQp,'b','linewidth',1.5)
axis([1 1000 400 1900])
set(GCA, 'FontSize',12)
set(gca,'xTick',[1 10 100 1000])
set(gca,'xTicklabel',{'1'; '10'; '100'; '1000';})
legend('Prognose', '95% KI oben', '95% KI unten')
title('Inn 1870 - 2005: Prognose und Konfidenzintervalle')
box off
grid
hold off